pub struct PathMatchers { /* private fields */ }Expand description
[POL]: Kontener przechowujący kolekcję silników dopasowujących ścieżki. [ENG]: A container holding a collection of path matching engines.
Implementations
Sourceimpl PathMatchers
impl PathMatchers
Sourcepub fn new<I, S>(patterns: I, case_sensitive: bool) -> Result<Self, Error>
pub fn new<I, S>(patterns: I, case_sensitive: bool) -> Result<Self, Error>
[POL]: Tworzy nową instancję, kompilując listę wzorców po uprzednim rozwinięciu klamer. [ENG]: Creates a new instance by compiling a list of patterns after performing brace expansion.
Sourcepub fn is_match(&self, path: &str, env: &HashSet<&str>) -> bool
pub fn is_match(&self, path: &str, env: &HashSet<&str>) -> bool
[POL]: Weryfikuje, czy ścieżka spełnia warunki narzucone przez zbiór wzorców (w tym negacje). [ENG]: Verifies if the path meets the conditions imposed by the pattern set (including negations).
Sourcepub fn evaluate<I, S, OnMatch, OnMismatch>(
&self,
paths: I,
env: &HashSet<&str>,
strategy: SortStrategy,
show_mode: ShowMode,
on_match: OnMatch,
on_mismatch: OnMismatch,
) -> MatchStats
pub fn evaluate<I, S, OnMatch, OnMismatch>( &self, paths: I, env: &HashSet<&str>, strategy: SortStrategy, show_mode: ShowMode, on_match: OnMatch, on_mismatch: OnMismatch, ) -> MatchStats
[POL]: Ewaluuje zbiór ścieżek, sortuje je i wykonuje odpowiednie domknięcia. [ENG]: Evaluates a set of paths, sorts them, and executes respective closures.